==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");

define("_YOURNAME","Dein Name");

define("_OK","Ok!");


define("_ALLOWEDHTML","erlaubter HTML Code:");
define("_EXTRANS","HTML Code zu Text umwandeln");
define("_HTMLFORMATED","HTML formatiert");
define("_PLAINTEXT","einfacher Text");
define("_ARTICLES","Artikel");
define("_SUBMITNEWS","News schreiben");
define("_SUBMITADVICE","Bitte benutze dieses Formular f&uuml;r Deinen Artikel und &uuml;berprfe Deinen Eintrag sorgf&auml;ltig.<br>Anschliessend wird der Artikel vom Admin best&auml;tigt und ggf. &uuml;berarbeitet.");
define("_SUBTITLE","&Uuml;berschrift");
define("_BEDESCRIPTIVE","m&ouml;glichst aussagekr&auml;ftig und klar");
define("_BADTITLES","Vermeide nichtssagende Titel wie 'Bitte Lesen' oder 'Artikel'");

define("_HTMLISFINE","HTML ist erlaubt, aber bitte URLS und HTML-Tags sorgf&auml;ltig &uuml;berpr&uuml;fen!");
define("_AREYOUSURE","Bist Du sicher, dass Du eine URL eingef&uuml;gt hast?  Auf Fehler gepr&uuml;ft?");
define("_SUBPREVIEW","Du musst Dir erst eine Voransicht anzeigen lassen, bevor Du den Artikel abschicken kannst.");
define("_SELECTTOPIC","Thema ausw&auml;hlen");
define("_NEWSUBPREVIEW","Artikel- Voransicht");
define("_STORYLOOK","So wird Dein Artikel aussehen:");
define("_CHECKSTORY","Vor dem Abschicken bitte Text, Links usw. &uuml;berpr&uuml;fen!");
define("_THANKSSUB","Herzlichen Dank f&uuml;r Ihren Beitrag!");
define("_SUBSENT","Dein Artikel wurde empfangen...");
define("_SUBTEXT","...und in K&uuml;rze von uns gesichtet und ver&ouml;ffentlicht werden.");
define("_WEHAVESUB","Zur Zeit warten");
define("_WAITING","Beitr&auml;ge auf die Ver&ouml;ffentlichung.");
define("_PREVIEW","Vorschau");
define("_NEWUSER","neuer Benutzer");
define("_USCORE","Wertung");
define("_DATE","Datum");
define("_STORYTEXT","Beitrags-Aufmacher");
define("_EXTENDEDTEXT","Erweiterter Text");
define("_LANGUAGE","Sprache");
define("_JANUARY","Januar");
define("_FEBRUARY","Februar");
define("_MARCH","M&auml;rz");
define("_APRIL","April");
define("_MAY","Mai");
define("_JUNE","Juni");
define("_JULY","Juli");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","Oktober");
define("_NOVEMBER","November");
define("_DECEMBER","Dezember");
define("_SELECTMONTH2VIEW","W&Auml;hle einen Monat der angezeigt werden soll:");
define("_SHOWALLSTORIES","Zeige ALLE Stories");
define("_STORIESARCHIVE","Stories Archiv");
define("_ACTIONS","Aktionen");
define("_ARCHIVESINDEX","Stories Archiv Index");
define("_ALLSTORIESARCH","Alle Stories");
define("_NEXTPAGE","N&auml;chste Seite");
define("_PREVIOUSPAGE","Vorhergehende Seite");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");
define("_YOURNAME","Dein Name");
define("_OK","Ok!");
define("_ALLOWEDHTML","erlaubter HTML Code:");
define("_EXTRANS","HTML Code zu Text umwandeln");
define("_HTMLFORMATED","HTML formatiert");
define("_PLAINTEXT","einfacher Text");
define("_ARTICLES","Artikel");
define("_SUBMITNEWS","News schreiben");
define("_SUBMITADVICE","Bitte benutze dieses Formular f&uuml;r Deinen Artikel und &uuml;berprfe Deinen Eintrag sorgf&auml;ltig.<br>Anschliessend wird der Artikel vom Admin best&auml;tigt und ggf. &uuml;berarbeitet.");
define("_SUBTITLE","&Uuml;berschrift");
define("_BEDESCRIPTIVE","m&ouml;glichst aussagekr&auml;ftig und klar");
define("_BADTITLES","Vermeide nichtssagende Titel wie 'Bitte Lesen' oder 'Artikel'");
define("_HTMLISFINE","HTML ist erlaubt, aber bitte URLS und HTML-Tags sorgf&auml;ltig &uuml;berpr&uuml;fen!");
define("_AREYOUSURE","Bist Du sicher, dass Du eine URL eingef&uuml;gt hast?  Auf Fehler gepr&uuml;ft?");
define("_SUBPREVIEW","Du musst Dir erst eine Voransicht anzeigen lassen, bevor Du den Artikel abschicken kannst.");
define("_SELECTTOPIC","Thema ausw&auml;hlen");
define("_NEWSUBPREVIEW","Artikel- Voransicht");
define("_STORYLOOK","So wird Dein Artikel aussehen:");
define("_CHECKSTORY","Vor dem Abschicken bitte Text, Links usw. &uuml;berpr&uuml;fen!");
define("_THANKSSUB","Herzlichen Dank f&uuml;r Ihren Beitrag!");
define("_SUBSENT","Dein Artikel wurde empfangen...");
define("_SUBTEXT","...und in K&uuml;rze von uns gesichtet und ver&ouml;ffentlicht werden.");
define("_WEHAVESUB","Zur Zeit warten");
define("_WAITING","Beitr&auml;ge auf die Ver&ouml;ffentlichung.");
define("_PREVIEW","Vorschau");
define("_NEWUSER","neuer Benutzer");
define("_USCORE","Wertung");
define("_DATE","Datum");
define("_STORYTEXT","Beitrags-Aufmacher");
define("_EXTENDEDTEXT","Erweiterter Text");
define("_LANGUAGE","Sprache");
define("_SELECTMONTH2VIEW","W&Auml;hle einen Monat der angezeigt werden soll:");
define("_SHOWALLSTORIES","Zeige ALLE Stories");
define("_STORIESARCHIVE","Stories Archiv");
define("_ACTIONS","Aktionen");
define("_ARCHIVESINDEX","Stories Archiv Index");
define("_ALLSTORIESARCH","Alle Stories");
define("_NEXTPAGE","N&auml;chste Seite");
define("_PREVIOUSPAGE","Vorhergehende Seite");


?>
